package jp.co.sds_corp.hibiya.monitor;

import java.awt.Dialog;
import java.awt.Font;
import java.awt.Frame;
import java.awt.Window;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.ResourceBundle;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.table.AbstractTableModel;

import jp.co.sds_corp.hibiya.connector.DirectConnector;
import jp.co.sds_corp.hibiya.connector.IConnector;
import jp.co.sds_corp.hibiya.monitor.checker.ICheckerPanel;
import jp.co.sds_corp.hibiya.server.CheckerChangeEvent;
import jp.co.sds_corp.hibiya.server.IChecker;
import jp.co.sds_corp.hibiya.server.ICheckerListener;
import jp.co.sds_corp.util.common.CmnProperty;
import jp.co.sds_corp.util.log.CmnLogger;
import jp.co.sds_corp.util.window.WindowUtility;

/**
* {@link IChecker}の設定を行うダイアログです。
*/
public class CheckerDialog extends JDialog implements ICheckerListener
{
	private static final long serialVersionUID = 1L;
	static CmnLogger logger = CmnLogger.getInstance();
	JButton BTN_OK = new JButton( "OK" );
	JButton BTN_APPLY = new JButton( "Apply" );
	JButton BTN_CANCEL = new JButton( "Cancel" );
	JTabbedPane tab = null;
	CmnProperty		res;

	SetupParam		setup;
	IConnector		con;
	MonitorParam	prm;
	IChecker		chk;
	JPanel			chkPnl;
	ICheckerPanel	panel;
	ThresholdPanel	thrPnl;
	ActionPanel		actPnl;
	HistoryPanel	histPnl;
	GraphPanel		grfPnl;
	StatusPanel		statPnl;
	int			nRes = -1;

	public CheckerDialog( Frame parent, SetupParam setup ) {
		super( parent );
		this.setup = setup;
		createControls();
	}

	public CheckerDialog( Dialog parent, SetupParam setup ) {
		super( parent );
		this.setup = setup;
		createControls();
	}

	private void createControls() {
		res = new CmnProperty( "resource.monitor" );
		setModal( true );
		setResizable( false );
		String text = res.getString( "checker.title" );
		setTitle( text );
		setSize( 477, 421 );
		getContentPane().setLayout( new BoxLayout(
			getContentPane(), BoxLayout.Y_AXIS ));

		chkPnl = new JPanel();
		actPnl = createActionPanel();
		thrPnl = createThresholdPanel();
		statPnl = createStatusPanel();
		histPnl = createHistoryPanel();
		grfPnl = createGraphPanel();

		tab = new JTabbedPane();
		getContentPane().add( tab );
		addTab();

		WindowUtility.setHideOnEscape( this );

		Box box1 = new Box( BoxLayout.X_AXIS );
		text = res.getString( "checker.button.ok.text" );
		BTN_OK = new JButton( text );
		text = res.getString( "checker.button.apply.text" );
		BTN_APPLY = new JButton( text );
		text = res.getString( "checker.button.cancel.text" );
		BTN_CANCEL = new JButton( text );
		box1.add( BTN_OK );
		box1.add( BTN_APPLY );
		box1.add( BTN_CANCEL );
		getContentPane().add( box1 );
		getRootPane().setDefaultButton( BTN_OK );

		Font	f = new Font( "Dialog", Font.PLAIN, 14 );
		setFont( f );

		BTN_OK.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent ev ) {
				onOk();
			}
		});
		BTN_APPLY.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent ev ) {
				onApply();
			}
		});
		BTN_CANCEL.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent ev ) {
				onCancel();
			}
		});

		addWindowListener( new WindowAdapter() {
			public void windowClosing( WindowEvent ev ) {
				onCancel();
			}
		} );
	}

	ActionPanel createActionPanel() {
		return new ActionPanel( (Window )getParent(), setup );
	}

	ThresholdPanel createThresholdPanel() {
		return new ThresholdPanel( (Window )getParent(), setup );
	}

	StatusPanel createStatusPanel() {
		return new StatusPanel( (Window )getParent(), setup );
	}

	HistoryPanel createHistoryPanel() {
		return new HistoryPanel( (Window )getParent(), setup );
	}

	GraphPanel createGraphPanel() {
		return new GraphPanel( (Window )getParent(), setup );
	}

	void addTab() {
		String text;

		tab.removeAll();
		text = res.getString( "checker.tab1.text", null );
		if ( text != null ) {
			tab.addTab( text, chkPnl );
		}
		text = res.getString( "checker.tab2.text", null );
		if ( text != null ) {
			tab.addTab( text, thrPnl );
		}
		text = res.getString( "checker.tab3.text", null );
		if ( text != null ) {
			tab.addTab( text, actPnl );
		}
		text = res.getString( "checker.tab4.text", null );
		if ( text != null ) {
			tab.addTab( text, statPnl );
		}
		text = res.getString( "checker.tab5.text", null );
		if ( text != null ) {
			tab.addTab( text, histPnl );
		}
		text = res.getString( "checker.tab6.text", null );
		if ( text != null ) {
			tab.addTab( text, grfPnl );
		}
	}

	public void setFont( Font f ) {
		actPnl.setFont( f );
		statPnl.setFont( f );
		histPnl.setFont( f );
		grfPnl.setFont( f );
	}

	public void setVisible( boolean var ) {
		if ( var ) {
			nRes = -1;
		} else {
			con.removeCheckerListener( this );
		}
		super.setVisible( var );
	}

	public void onOk() {
		if ( !onApply()) {
			return;
		}
		setVisible( false );
		nRes = 1;
	}

	public boolean onApply() {
		IChecker.Status stat = chk.getCheckerStatus();
		try {
			panel.checkSetup();
			panel.setupChecker( chk );
			thrPnl.setupChecker( chk );
			chk.getActionList().clear();
			chk.getActionList().addAll( actPnl.listActions() );
			chk.clearCheckerStatus();
			ResourceBundle ress = ResourceBundle.getBundle( "resource.server" );
			String text = ress.getString( "checker.init" );
			CheckerChangeEvent se = new CheckerChangeEvent(
				chk, stat, IChecker.Status.INIT, null,
				chk.getType() + " [" + chk.getName() + "] " + text );
			chk.fireCheckerChange( se );
		} catch ( Exception ex ) {
			logger.error( this, "error:" + ex );
			String title = res.getString( "checker.setup.err1.title" );
			String msg = ex.getMessage();
			if ( msg == null ) {
				msg = ex.toString();
			}
			JOptionPane.showMessageDialog( this,
				msg, title, JOptionPane.ERROR_MESSAGE );
			return false;
		}
		return true;
	}

	public void onCancel() {
		nRes = 0;
		setVisible( false );
	}

	/**
	* ICheckerの状態に変更があった場合に呼び出されます。
	* @param    ev		状態の変更内容を指定します。
	*/
	public void checkerChanged( CheckerChangeEvent ev ) throws Exception {
		IChecker src = (IChecker )ev.getSource();
		// if ( chk == null || src.getHashCode() != chk.getHashCode()) {
		if ( chk == null || !src.getName().equals( chk.getName()) ) {
			return;
		}
		statPnl.checkerChanged( ev );
		histPnl.checkerChanged( ev );
	}

	public void setData( IConnector con, MonitorParam prm, IChecker chk ) {
		if ( this.panel != null ) {
			chkPnl.remove((JPanel )this.panel );
		}
		this.con = con;
		this.prm = prm;
		this.chk = chk;
		this.panel = prm.getPanel();

		if ( con instanceof DirectConnector ) {
			setEnabled( true );
		} else {
			setEnabled( false );
		}
		con.addCheckerListener( this );
		panel.setConnector( con );
		panel.setChecker( chk );
		panel.setThresholdPanel( thrPnl );
		thrPnl.setChecker( chk );
		actPnl.clearAction();
		actPnl.addActionList( chk.getActionList() );
		((AbstractTableModel )actPnl.table.getModel()).fireTableDataChanged();
		statPnl.setChecker( chk );
		histPnl.setHistoryList( chk.listHistory() );
		grfPnl.setParam( con, chk,
						prm.getGraphSetupParam(), prm.listGraphParam() );
		chkPnl.add((JPanel )panel );
	}

	public int getResult() {
		return nRes;
	}

	public void setEnabled( boolean bEn ) {
		if ( !bEn ) {
			BTN_CANCEL.requestFocus();
		}
		panel.setEnabled( bEn );
		actPnl.setEnabled( bEn );
		thrPnl.setEnabled( bEn );
		BTN_OK.setEnabled( bEn );
		BTN_APPLY.setEnabled( bEn );
	}

}
