package jp.co.sds_corp.hibiya.monitor;

import java.awt.Color;
import java.text.DecimalFormat;

import jp.co.sds_corp.hibiya.connector.IConnector;
import jp.co.sds_corp.hibiya.server.IChecker;
import jp.co.sds_corp.util.common.ColorDecoder;
import jp.co.sds_corp.util.config.IConfigSavable;
import jp.co.sds_corp.util.config.IConfigurable;
import jp.co.sds_corp.util.config.IConfiguration;

/**
* グラフの設定を保持します。
*/
public class GraphParam implements IConfigurable, IConfigSavable
{
	String	value;	// 値
	DecimalFormat	format;	// 値の書式
	Number	max;	// 最大値
	Number	min;	// 最小値
	Color	color;	// グラフの色
	IConnector	connector;	// connector
	IChecker	checker;	// checker

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		IConfiguration c;
		value = config.getAttributes().get( "value" );
		String var;
		var = config.getAttributes().get( "format", null );
		if ( var == null ) {
			var = "#";
		}
		format = new DecimalFormat( var );
		var = config.getAttributes().get( "max", null );
		if ( var != null ) {
			max = format.parse( var );
		}
		var = config.getAttributes().get( "min", null );
		if ( var != null ) {
			min = format.parse( var );
		}
		var = config.getAttributes().get( "color", null );
		if ( var != null ) {
			color = ColorDecoder.decode( var );
		}
	}

	/**
	* 設定情報を保存します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		config.setAttribute( "value", getValue() );
		config.setAttribute( "color", ColorDecoder.encode( getColor() ));
	}

	public void setData( IConnector con, IChecker chk ) {
		this.connector = con;
		this.checker = chk;
	}

	/**
	* 値を設定します。
	* @param	var		設定するデータ
	*/
	public void setValue( String var ) {
		this.value = var;
	}
	/**
	* 値を取得します。
	* @return	値
	*/
	public String getValue() {
		return value;
	}

	/**
	* 値の書式を設定します。
	* @param	var		設定するデータ
	*/
	public void setFormat( DecimalFormat var ) {
		this.format = var;
	}
	/**
	* 値の書式を取得します。
	* @return	値の書式
	*/
	public DecimalFormat getFormat() {
		return format;
	}

	/**
	* 最大値を設定します。
	* @param	var		設定するデータ
	*/
	public void setMax( Number var ) {
		this.max = var;
	}
	/**
	* 最大値を取得します。
	* @return	最大値
	*/
	public Number getMax() {
		return max;
	}

	/**
	* 最小値を設定します。
	* @param	var		設定するデータ
	*/
	public void setMin( Number var ) {
		this.min = var;
	}
	/**
	* 最小値を取得します。
	* @return	最小値
	*/
	public Number getMin() {
		return min;
	}

	/**
	* グラフの色を設定します。
	* @param	var		設定するデータ
	*/
	public void setColor( Color var ) {
		this.color = var;
	}
	/**
	* グラフの色を取得します。
	* @return	グラフの色
	*/
	public Color getColor() {
		return color;
	}

	/**
	* connectorを設定します。
	* @param	var		設定するデータ
	*/
	public void setConnector( IConnector var ) {
		this.connector = var;
	}
	/**
	* connectorを取得します。
	* @return	connector
	*/
	public IConnector getConnector() {
		return connector;
	}

	/**
	* checkerを設定します。
	* @param	var		設定するデータ
	*/
	public void setChecker( IChecker var ) {
		this.checker = var;
	}
	/**
	* checkerを取得します。
	* @return	checker
	*/
	public IChecker getChecker() {
		return checker;
	}

}
