package jp.co.sds_corp.hibiya.monitor;

import java.awt.BorderLayout;
import java.awt.Dialog;
import java.awt.Font;
import java.awt.Frame;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ResourceBundle;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.border.TitledBorder;

import jp.co.sds_corp.util.window.FileSelector;
import jp.co.sds_corp.util.window.VolumeSetupPanel;
import jp.co.sds_corp.util.window.WindowUtility;

/**
* Hibiya Monitor全体の設定を行います。
*/
public class SetupDialog extends JDialog
{
	private static final long serialVersionUID = 1L;
	SetupParam		setup;
	MonitorParam	prm;
	ResourceBundle	res;

	JTabbedPane		tp;
	JButton BTN_OK = new JButton( "OK" );
	JButton BTN_CANCEL = new JButton( "Cancel" );
	JCheckBox CHK_FRONT;

	FileSelector		ip1, ip2, ip3;
	VolumeSetupPanel	vp;
	int		nRes = -1;

	public SetupDialog( Frame parent, SetupParam setup ) {
		super( parent );
		this.setup = setup;
		createControls();
	}

	public SetupDialog( Dialog parent, SetupParam setup ) {
		super( parent );
		this.setup = setup;
		createControls();
	}

	public SetupDialog() {
		super();
		createControls();
	}

	private void createControls() {
		res = ResourceBundle.getBundle( "resource.monitor" );
		String text;
		setModal( true );
		setResizable( false );
		text = res.getString( "setup.title" );
		setTitle( text );
		setSize( 477, 421 );
		getContentPane().setLayout(
			new BoxLayout( getContentPane(), BoxLayout.Y_AXIS ));
		Font	f = new Font( "Dialog", Font.PLAIN, 14 );
		setFont( f );

		WindowUtility.setHideOnEscape( this );

		tp = new JTabbedPane();
		text = res.getString( "setup.tab.title" );
		tp.add( createSetupPanel(), text );

		getContentPane().add( tp );
		Box box1 = new Box( BoxLayout.X_AXIS );
		box1.add( BTN_OK );
		box1.add( BTN_CANCEL );
		getContentPane().add( box1 );
		getRootPane().setDefaultButton( BTN_OK );

		BTN_OK.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent ev ) {
				onOk();
			}
		});
		BTN_CANCEL.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent ev ) {
				onCancel();
			}
		});
	}

	private JPanel createSetupPanel() {
		JPanel pnl1 = new JPanel();
		pnl1.setLayout( new BorderLayout() );
		pnl1.add( createIconPanel(), BorderLayout.NORTH );
		vp = (VolumeSetupPanel )createVolumePanel();
		pnl1.add( vp, BorderLayout.CENTER );
		pnl1.add( createEtcPanel(), BorderLayout.SOUTH );

		return pnl1;
	}

	protected JPanel createIconPanel() {
		JPanel pnl = new JPanel();
		pnl.setLayout( new BoxLayout( pnl, BoxLayout.Y_AXIS ));
		ip1 = new FileSelector( ".", "Info", FileSelector.Type.IMAGE );
		pnl.add( ip1 );
		ip2 = new FileSelector( ".", "Warn", FileSelector.Type.IMAGE );
		pnl.add( ip2 );
		ip3 = new FileSelector( ".", "Err", FileSelector.Type.IMAGE );
		String text = res.getString( "setup.icon.title" );
		pnl.setBorder( new TitledBorder( text ));
		pnl.add( ip3 );
		return pnl;
	}

	protected JPanel createVolumePanel() {
		JPanel pnl = new VolumeSetupPanel();
		String text = res.getString( "setup.volume.title" );
		pnl.setBorder( new TitledBorder( text ));
		return pnl;
	}

	protected JPanel createEtcPanel() {
		JPanel pnl = new JPanel();
		pnl.setLayout( new GridLayout( 1, 1 ));
		String text;
		text = res.getString( "setup.etc.title" );
		pnl.setBorder( new TitledBorder( text ));
		text = res.getString( "setup.etc.front.text" );
		CHK_FRONT = new JCheckBox( text );
		CHK_FRONT.setEnabled( false );
		pnl.add( CHK_FRONT );
		return pnl;
	}

	public void setVisible( boolean var ) {
		if ( var ) {
			tp.setSelectedIndex( 0 );
/*
			ip1.setSelection( setup.getIconName( SetupParam.Level.INFO ));
			ip2.setSelection( setup.getIconName( SetupParam.Level.WARN ));
			ip3.setSelection( setup.getIconName( SetupParam.Level.ERR ));
*/
			vp.setVolume( setup.getVolume() );
		}

		super.setVisible( var );
	}

	public void onOk() {
		setVisible( false );
		nRes = 1;
/*
		setup.setIconName( SetupParam.Level.INFO, ip1.getSelection() );
		setup.setIconName( SetupParam.Level.WARN, ip2.getSelection() );
		setup.setIconName( SetupParam.Level.ERR, ip3.getSelection() );
*/
		setup.setVolume( vp.getVolume() );
	}

	public void onCancel() {
		nRes = 0;
		setVisible( false );
	}

	public int getResult() {
		return nRes;
	}

}
