package	jp.co.sds_corp.hibiya.monitor.action;

import java.util.ResourceBundle;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import jp.co.sds_corp.hibiya.action.IAction;
import jp.co.sds_corp.hibiya.filter.EventFilter;
import jp.co.sds_corp.hibiya.server.IChecker;
import jp.co.sds_corp.util.window.ValuePanel;

/**
* {@link IAction}の各種設定をするPanelのための基底クラスです。
* @author	小見山　聡
*/
public abstract class AbstractPanel extends JPanel implements IActionPanel
{
	private static final long serialVersionUID = 1L;
	ResourceBundle	res;
	String[] stats = {
		"INIT", "OK", "WARN", "NG", "DEL"
	};
	IChecker.Status[] nStats = {
		IChecker.Status.INIT,
		IChecker.Status.OK,
		IChecker.Status.WARN,
		IChecker.Status.NG,
		IChecker.Status.DEL
	};
	JComboBox	CMB_MINSTAT;
	ValuePanel	VAL_MINSTAT;
	JCheckBox	CHK_UNIQ;
	Box			PNL_UNIQ = new Box( BoxLayout.X_AXIS );
	IAction	action;

	AbstractPanel() {
		res = ResourceBundle.getBundle( "resource.monitor" );
		String text;
		CMB_MINSTAT = new JComboBox( stats );
		text = res.getString( "action.minstat.text" );
		VAL_MINSTAT = new ValuePanel( ValuePanel.ReturnType.STRING, text, CMB_MINSTAT );
		text = res.getString( "action.uniq.text" );
		CHK_UNIQ = new JCheckBox( text );
		PNL_UNIQ.add( CHK_UNIQ );
		PNL_UNIQ.add( Box.createHorizontalGlue() );
	}

	/**
	* {@link IAction}を設定します。
	*/
	public void setAction( IAction action ) {
		this.action = action;
		EventFilter flt = (EventFilter )action.getFilter();
		for ( int i = 0; i < nStats.length; i++ ) {
			if ( flt.getMinStatus() == nStats[i] ) {
				CMB_MINSTAT.setSelectedIndex( i );
				break;
			}
		}
		if ( flt.isUnique()) {
			CHK_UNIQ.setSelected( true );
		} else {
			CHK_UNIQ.setSelected( false );
		}
	}

	/**
	* {@link IAction}を取得します。
	*/
	public IAction getAction() {
		return action;
	}

	public void clear() {
		CMB_MINSTAT.setSelectedIndex( 2 );
		CHK_UNIQ.setSelected( true );
	}

	public void updateAction() throws Exception {
		EventFilter flt = (EventFilter )action.getFilter();
		flt.setMinStatus( nStats[CMB_MINSTAT.getSelectedIndex()] );
		if ( CHK_UNIQ.isSelected()) {
			flt.setUnique( true );
		} else {
			flt.setUnique( false );
		}
	}

	public void setEnabled( boolean bEn ) {
		super.setEnabled( bEn );
		VAL_MINSTAT.setEnabled( bEn );
		CHK_UNIQ.setEnabled( bEn );
	}

}

