package	jp.co.sds_corp.hibiya.monitor.action;

import java.io.UnsupportedEncodingException;
import java.util.ResourceBundle;

import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.border.TitledBorder;

import jp.co.sds_corp.hibiya.action.IAction;
import jp.co.sds_corp.hibiya.action.SyslogAction;
import jp.co.sds_corp.util.syslog.Facility;
import jp.co.sds_corp.util.syslog.Priority;
import jp.co.sds_corp.util.window.ValuePanel;

/**
* Syslogの設定を行うJPanelです。
* @author	小見山　聡
*/
public class SyslogPanel extends AbstractPanel
{
	private static final long serialVersionUID = 1L;
	static final String SEL_NONE = "(None)";
	ValuePanel	VAL_HOST;
	ValuePanel	VAL_PORT;
	ValuePanel	VAL_FAC;
	ValuePanel	VAL_PRI;
	ValuePanel	VAL_ENC;
	ResourceBundle	res;

	/**
	* このパネルを初期化します。
	*/
	public SyslogPanel() {
		res = ResourceBundle.getBundle( "resource.monitor" );
		String text;
		text = res.getString( "action.syslog.title" );
		setBorder( new TitledBorder( text ));
		setLayout( new BoxLayout( this, BoxLayout.Y_AXIS ));

		text = res.getString( "action.syslog.host.text" );
		VAL_HOST = new ValuePanel( ValuePanel.ReturnType.STRING, text );
		text = res.getString( "action.syslog.port.text" );
		VAL_PORT = new ValuePanel( ValuePanel.ReturnType.INT, text );
		JComboBox cmb;
		cmb = new JComboBox( Facility.listMessages() );
		cmb.insertItemAt( SEL_NONE, 0 );
		text = res.getString( "action.syslog.facility.text" );
		VAL_FAC = new ValuePanel( ValuePanel.ReturnType.STRING, text, cmb );
		cmb = new JComboBox( Priority.listMessages() );
		cmb.insertItemAt( SEL_NONE, 0 ); 
		text = res.getString( "action.syslog.priority.text" );
		VAL_PRI = new ValuePanel( ValuePanel.ReturnType.STRING, text, cmb );
		text = res.getString( "action.syslog.encode.text" );
		VAL_ENC = new ValuePanel( ValuePanel.ReturnType.STRING, text );

		add( VAL_HOST );
		add( VAL_PORT );
		add( VAL_FAC );
		add( VAL_PRI );
		add( VAL_ENC );
		add( VAL_MINSTAT );
		add( PNL_UNIQ );
	}

	public void setAction( IAction action ) {
		super.setAction( action );
		if ( action == null ) {
			clear();
			return;
		}
		SyslogAction sa = (SyslogAction )action;
		VAL_HOST.setValue( sa.getHost() );
		VAL_PORT.setValue( String.valueOf( sa.getPort() ));
		if ( sa.getFacility() == null ) {
			VAL_FAC.setValue( SEL_NONE );
		} else {
			VAL_FAC.setValue( sa.getFacility() );
		}
		if ( sa.getPriority() == null ) {
			VAL_PRI.setValue( SEL_NONE );
		} else {
			VAL_PRI.setValue( sa.getPriority() );
		}
		VAL_ENC.setValue( sa.getEncode() );
	}

	public void setEnabled( boolean bEn ) {
		super.setEnabled( bEn );
		VAL_HOST.setEnabled( bEn );
		VAL_PORT.setEnabled( bEn );
		VAL_FAC.setEnabled( bEn );
		VAL_PRI.setEnabled( bEn );
		VAL_ENC.setEnabled( bEn );
	}

	public void clear() {
		super.clear();
		VAL_HOST.setValue( null );
		VAL_PORT.setValue( "514" );
		VAL_FAC.setValue( null );
		VAL_PRI.setValue( null );
		VAL_ENC.setValue( null );
	}

	public void updateAction() throws Exception {
		super.updateAction();
		String var;
		var = (String )VAL_HOST.getValue();
		if ( var == null || var.length() == 0 ) {
			String msg = res.getString( "action.syslog.err1.message" );
			throw( new Exception( msg ));
		}
		Integer nvar = (Integer )VAL_PORT.getValue();
		if ( nvar == null || nvar.intValue() <= 0 ) {
			String msg = res.getString( "action.syslog.err2.message" );
			throw( new Exception( msg ));
		}
		var = (String )VAL_ENC.getValue();
		if ( var != null && var.length() > 0 ) {
			try {
				"aあ".getBytes( var );
			} catch ( UnsupportedEncodingException uex ) {
				String msg = res.getString( "action.syslog.err3.message" );
				throw( new Exception( msg ));
			}
		}

		SyslogAction sa = (SyslogAction )action;
		sa.setHost( (String )VAL_HOST.getValue() );
		sa.setPort( ((Integer )VAL_PORT.getValue()).intValue() );
		var = (String )VAL_FAC.getValue();
		if ( var.equals( SEL_NONE )) {
			sa.setFacility( null );
		} else {
			sa.setFacility( var );
		}
		var = (String )VAL_PRI.getValue();
		if ( var.equals( SEL_NONE )) {
			sa.setPriority( null );
		} else {
			sa.setPriority( var );
		}
		var = (String )VAL_ENC.getValue();
		sa.setEncode( var );
	}

}

