package	jp.co.sds_corp.hibiya.monitor.connector;

import java.util.ResourceBundle;

import javax.swing.BoxLayout;

import jp.co.sds_corp.hibiya.connector.IConnector;
import jp.co.sds_corp.hibiya.connector.RMIConnector;
import jp.co.sds_corp.util.window.ValuePanel;

/**
* {@link RMIConnector}を設定するPanelです。
* @author	小見山　聡
*/
public class RMIPanel extends AbstractPanel
{
	private static final long serialVersionUID = 1L;
	ValuePanel	VAL_RHOST;
	ValuePanel	VAL_RPORT;
	ValuePanel	VAL_RNAME;
	ResourceBundle	res;

	/**
	* このパネルを初期化します。
	*/
	public RMIPanel() {
		res = ResourceBundle.getBundle( "resource.monitor" );
		createPanel();
	}

	private void createPanel() {
		setLayout( new BoxLayout( this, BoxLayout.Y_AXIS ));
		add( VAL_NAME );
		String text;
		text = res.getString( "connector.rmi.host.text" );
		VAL_RHOST = new ValuePanel( ValuePanel.ReturnType.STRING, text );
		add( VAL_RHOST );
		text = res.getString( "connector.rmi.port.text" );
		VAL_RPORT = new ValuePanel( ValuePanel.ReturnType.INT, text );
		add( VAL_RPORT );
		text = res.getString( "connector.rmi.name.text" );
		VAL_RNAME = new ValuePanel( ValuePanel.ReturnType.STRING, text );
		add( VAL_RNAME );
		add( VAL_INT );
		add( PNL_BLANK );
	}

	public void setConnector( IConnector connector ) {
		super.setConnector( connector );
		if ( connector == null ) {
			clear();
			return;
		}
		RMIConnector rmi = (RMIConnector )connector;
		VAL_RHOST.setValue( rmi.getHost() );
		VAL_RPORT.setValue( String.valueOf( rmi.getPort() ));
		VAL_RNAME.setValue( rmi.getRegistryName() );
	}

	/**
	* 設定内容をクリアします。
	*/
	public void clear() {
		super.clear();
		VAL_RHOST.setValue( null );
		VAL_RPORT.setValue( null );
		VAL_RNAME.setValue( null );
	}

	/**
	* 現在の{@link IConnector}を入力された内容で設定します。
	*/
	public void updateConnector() throws Exception {
		String var;
		var = (String )VAL_NAME.getValue();
		if ( var == null || var.length() == 0 ) {
			String msg = res.getString( "connector.err4.message" );
			throw( new Exception( msg ));
		}
		var = (String )VAL_RHOST.getValue();
		if ( var == null || var.length() == 0 ) {
			String msg = res.getString( "connector.rmi.err1.message" );
			throw( new Exception( msg ));
		}
		Integer nvar;
		nvar = (Integer )VAL_RPORT.getValue();
		if ( nvar == null || nvar.intValue() <= 0 ) {
			String msg = res.getString( "connector.rmi.err2.message" );
			throw( new Exception( msg ));
		}
		var = (String )VAL_RNAME.getValue();
		if ( var == null || var.length() == 0 ) {
			String msg = res.getString( "connector.rmi.err3.message" );
			throw( new Exception( msg ));
		}
		nvar = (Integer )VAL_INT.getValue();
		if ( nvar == null || nvar.intValue() <= 0 ) {
			String msg = res.getString( "connector.err5.message" );
			throw( new Exception( msg ));
		}

		super.updateConnector();
		RMIConnector rmi = (RMIConnector )connector;
		rmi.setHost( (String )VAL_RHOST.getValue() );
		rmi.setPort( ((Integer )VAL_RPORT.getValue()).intValue() );
		rmi.setRegistryName( (String )VAL_RNAME.getValue() );
	}

	public void setEnabled( boolean bEn ) {
		super.setEnabled( bEn );
		VAL_RHOST.setEnabled( bEn );
		VAL_RPORT.setEnabled( bEn );
		VAL_RNAME.setEnabled( bEn );
	}

}

